@@ -44,6 +44,8 @@ pub enum TailwindErrorKind {
         /// The name of the undefined variable
         name: String,
     },
+    /// Parsing not complete
+    Incomplete,
     /// A forbidden cst_node encountered
     Unreachable,
     // #[error(transparent)]
@@ -156,6 +158,10 @@ impl Display for TailwindErrorKind {
             Self::UndefinedVariable { name } => {
                 write!(f, "RuntimeError: Variable {} not found in scope", name)
             }
+            Self::Incomplete => {
+                f.write_str("InternalError: ")?;
+                f.write_str("Parsing incomplete!")
+            }
             Self::Unreachable => {
                 f.write_str("InternalError: ")?;
                 f.write_str("Entered unreachable code!")
